@@ -49,16 +49,8 @@ uint_8  * cInStream::tsdata;
 cBounce * cInStream::bounce;
 
 cInStream::cInStream(int Pid, spdif *dev, ctrl_t &up, cBounce *bPtr)
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10318
-:cReceiver(0, -1, Pid),
-#else
-:cReceiver(0, -1, 1, Pid),
-#endif
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10300
+:cReceiver(tChannelID(), -1, Pid),
  cThread("bso(instream): Forwarding bitstream"),
-#else
- cThread(),
-#endif
  ctrl(), wait(), spdifDev(dev), setup(up)
 {
     flags = 0;
@@ -175,9 +167,6 @@ void cInStream::Action(void)
     }
     debug_chl("%s %d\n", __FUNCTION__, __LINE__);
 
-#if defined(VDRVERSNUM) && VDRVERSNUM < 10300
-    dsyslog("INSTREAM: Forwarding bitstream thread started (pid=%d)", getpid());
-#endif
     bounce->takeio();
     while (test_flag(ACTIVE)) {
 	ssize_t len;
@@ -215,9 +204,6 @@ void cInStream::Action(void)
     spdifDev->Close(this);
     clear_flag(BOUNDARY);
     curr->Reset();
-#if defined(VDRVERSNUM) && VDRVERSNUM < 10300
-    dsyslog("INSTREAM: Forwarding bitstream thread ended (pid=%d)", getpid());
-#endif
 out:
     ctrl.Lock();
     stream = NULL;
@@ -741,19 +727,12 @@ uint_16 cChannelOutSPDif::Apid = 0x1FFF;
 
 cChannelOutSPDif::cChannelOutSPDif(spdif &dev, ctrl_t &up, cBounce * bPtr, const char *script)
 :cStatus(),
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10300
  cThread("bso(channelout): Switching bitstream"),
-#else
- cThread(),
-#endif
  Channel(NULL), wait(), SPDIFmute(script), spdifDev(&dev), setup(up)
 {
     flags = 0;
     in = NULL;
     bounce = bPtr;
-#if defined(VDRVERSNUM) && VDRVERSNUM <= 10317
-    Player = NULL;
-#endif
 }
 
 cChannelOutSPDif::~cChannelOutSPDif(void)
@@ -769,11 +748,9 @@ bool cChannelOutSPDif::InTransferMode(void)
     if (!PrimaryDevice)
 	goto out;
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10342
     // Just missed a few years
     if (PrimaryDevice->Transferring())
 	goto out;
-#endif
 
     // Sanity check not be attached in transfer mode.
     // In this case the replay part should take the data
@@ -792,7 +769,6 @@ out:
     return true;
 }
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 //
 // Stop current attached input filer thread if any and wake up the
 // switching thread if a new audio track was choosen.  The Apid
@@ -849,7 +825,6 @@ void cChannelOutSPDif::SetAudioTrack(int Index, const char * const *Tracks)
 out:
     return;
 }
-#endif // VDRVERSNUM >= 10321
 
 void cChannelOutSPDif::Activate(bool onoff)
 {
@@ -889,9 +864,6 @@ out:
 void cChannelOutSPDif::Action(void)
 {
     set_flag(RUNNING);
-#if defined(VDRVERSNUM) && VDRVERSNUM < 10300
-    dsyslog("CHANNELOUT: Switching bitstream thread started (pid=%d)", getpid());
-#endif
 
     ctrl.Lock();
     while (test_flag(ACTIVE)) {
@@ -912,10 +884,6 @@ void cChannelOutSPDif::Action(void)
 	if (!GetCurrentAudioTrack(apid, type))		// Get audio pid and type
 	    continue;
 
-#if defined(VDRVERSNUM) && VDRVERSNUM <= 10317
-	if (strcmp(type, audioType) != 0)		// The green button switch
-	    continue;					// changes languages only
-#endif
 	if (Apid == apid)
 	    continue;
 
@@ -923,9 +891,6 @@ void cChannelOutSPDif::Action(void)
     }
     ctrl.Unlock();
 
-#if defined(VDRVERSNUM) && VDRVERSNUM < 10300
-    dsyslog("CHANNELOUT: Switching bitstream thread ended (pid=%d)", getpid());
-#endif
     clear_flag(ACTIVE);
     clear_flag(RUNNING);
 }
@@ -935,20 +900,8 @@ void cChannelOutSPDif::AudioSwitch(uint_16 apid, const char* type, const cChanne
     sw.Lock();
     if (in) AttachReceiver(false);	// Do _not_ reset Channel
 
-    if (Replaying())
+    if (!Replaying())
     {
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10317
-	goto out;	
-#else
-	if (Player) {
-	    int numtracks = Player->NumAudioTracks();
-	    int num = (int)apid - 1;
-
-	    if (0 <= num && num < numtracks)
-		Player->SetAudioTrack(num);
-	}
-#endif
-    } else {
 	if (channel)
 	    Channel = channel;
 
@@ -989,10 +942,8 @@ void cChannelOutSPDif::AttachReceiver(bool onoff)
 
     if (in) {
 	in->Clear();
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10325
 	if (PrimaryDevice)
 	    PrimaryDevice->Detach(in);
-#endif
 	delete in;
 	in = NULL;
 	if (bounce)
@@ -1075,18 +1026,11 @@ out:
     return;
 }
 
-#if VDRVERSNUM >= 10338
 void cChannelOutSPDif::Recording(const cDevice *Device, const char *Name, const char *FileName, bool On)
-#else
-void cChannelOutSPDif::Recording(const cDevice *Device, const char *Name)
-#endif
 {
     sw.Lock();
     cDevice *PrimaryDevice  = cDevice::PrimaryDevice();
     cDevice *ReceiverDevice = cTransferControl::ReceiverDevice();
-#if VDRVERSNUM < 10338
-    bool On = (Name != NULL);
-#endif
 
     if (!PrimaryDevice)
 	goto out;
@@ -1109,21 +1053,11 @@ out:
     IfNeededMuteSPDIF();		// On close the S/P-DIF is not muted anymore
 }
 
-#if VDRVERSNUM >= 10338
 void cChannelOutSPDif::Replaying(const cControl *Control, const char *Name, const char *FileName, bool On)
-#else
-void cChannelOutSPDif::Replaying(const cControl *Control, const char *Name)
-#endif
 {
     sw.Lock();
-#if VDRVERSNUM < 10338
-    bool On = (Name != NULL);
-#endif
 
     if (On) {
-#if defined(VDRVERSNUM) && VDRVERSNUM <= 10317
-	Player = (static_cast<const cControlPerm *>(Control))->Player();
-#endif
 	Channel = NULL;			// Reset Channel
 	if (in) AttachReceiver(false);
     }
@@ -1171,17 +1105,10 @@ out:
 
 bool cChannelOutSPDif::GetCurrentAudioTrack(uint_16 &apid, const char* &type, const cChannel *channel)
 {
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10317
     cDevicePerm *PrimaryDevice = static_cast<cDevicePerm *>(cDevice::PrimaryDevice());
     eTrackType CurrentAudioTrack = ttNone;
     const tTrackId *track;
     int num;
-#else
-    cDevice *PrimaryDevice = cDevice::PrimaryDevice();
-    uint_16 mpid = 0x1FFF;
-    uint_16 dpid = 0x1FFF;
-    int CurrentAudioTrack = 0;
-#endif
     bool ret = false;
 
     type = audioTypes[IEC_NONE];
@@ -1189,10 +1116,9 @@ bool cChannelOutSPDif::GetCurrentAudioTrack(uint_16 &apid, const char* &type, co
     if (!channel || !PrimaryDevice)
 	goto out;
 
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10317
-# ifndef  MAXDPIDS
-#  define MAXDPIDS 8
-# endif
+#ifndef  MAXDPIDS
+# define MAXDPIDS 8
+#endif
     if ((CurrentAudioTrack = PrimaryDevice->GetCurrentAudioTrack()) == ttNone)
 	goto out;
     track = PrimaryDevice->GetTrack(CurrentAudioTrack);
@@ -1213,36 +1139,6 @@ bool cChannelOutSPDif::GetCurrentAudioTrack(uint_16 &apid, const char* &type, co
 	    break;
 	}
     }
-#else
-    if (PrimaryDevice->GetAudioTracks(&CurrentAudioTrack) == NULL)
-	goto out;
-
-    switch (CurrentAudioTrack) {
-    case 0:
-	dpid = channel->Dpid1();
-	mpid = channel->Apid1();
-	break;
-    case 1:
-	dpid = channel->Dpid2();
-	mpid = channel->Apid2();
-	break;
-    default:
-	break;
-    }
-
-    if (dpid == 0 || dpid >= 0x1FFF) {
-	apid = mpid;
-	type = audioTypes[IEC_MP2];
-    } else {
-	if (strcmp(audioType, audioTypes[IEC_MP2]) == 0) {
-	    apid = mpid;
-	    type = audioTypes[IEC_MP2];
-	} else {
-	    apid = dpid;
-	    type = audioTypes[IEC_AC3];
-	}
-    }
-#endif
     ret = (apid && apid < 0x1FFF);
 out:
     return ret;
@@ -1250,42 +1146,18 @@ out:
 
 bool cChannelOutSPDif::AudioTrack(int num, const char* type, int &apid)
 {
-    if (Replaying())
-    {
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10317
+    if (Replaying()) {
 	apid = 0x1FFF;
-#else
-	if (Player) {
-	    int numtracks = Player->NumAudioTracks();
-	    if (0 <= num && num < numtracks && (strcmp(type, audioTypes[IEC_AC3]) != 0))
-		apid = num+1;
-	    else
-		apid = 0x1FFF;
-	}
-#endif
     } else {
 	apid = 0x1FFF;
 
 	if (!Channel)
 	   goto out;
 
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10317
 	if (num >= MAXAPIDS)
 	   goto out;
 
 	apid = (strcmp(type, audioTypes[IEC_AC3]) == 0) ? Channel->Dpid(num) : Channel->Apid(num);
-#else
-	switch (num) {
-	case 0:
-	    apid = (strcmp(type, audioTypes[IEC_AC3]) == 0) ? Channel->Dpid1() : Channel->Apid1();
-	    break;
-	case 1:
-	    apid = (strcmp(type, audioTypes[IEC_AC3]) == 0) ? Channel->Dpid2() : Channel->Apid2();
-	    break;
-	default:
-	    break;
-	}
-#endif
     }
 out:
     return (apid && apid < 0x1FFF);
@@ -1293,20 +1165,8 @@ out:
 
 uint_16 cChannelOutSPDif::AudioPid(void)
 {
-    if (Replaying())
-    {
-#if defined(VDRVERSNUM) && VDRVERSNUM > 10317
-	return 1;
-#else
-	if (Player) {
-	    int apid;
-	    Player->GetAudioTracks(&apid);
-	    return apid+1;
-	}
-#endif
-    } else if (in)
+    if (!Replaying())
 	return in->AudioPid();
-
     return Apid;
 }
 
