@@ -57,12 +57,8 @@ const uint_32 cMP2::bitrate_table[5][15] = {
 const uint_16 cMP2::magic = 0xffe0;
 
 cMP2::cMP2(unsigned int rate)
-#ifndef MP2_BURST_SIZE
-: iec60958(rate, SPDIF_BURST_SIZE, 0)		// 32ms max buffer
-#else
-: iec60958(rate, MP2_BURST_SIZE, 0)		// 24ms buffer
-#endif
- , running(false)
+: iec60958(rate, MP2_BURST_SIZE, 0),		// 24ms buffer
+running(false)
 {
     reset_scan();
     reset_count();
@@ -304,7 +300,7 @@ out:
 
 size_t cMP2::Stream(uint_8 *data, size_t cnt)
 {
-    size_t todo = MP2_BUFFER_SIZE;
+    size_t todo = MAD_BUFFER_MDLEN;	// mad.h says: MAD_BUFFER_MDLEN = 511 + 2048 + MAD_BUFFER_GUARD
 
     if (!running) Start();
 
@@ -312,7 +308,7 @@ size_t cMP2::Stream(uint_8 *data, size_t cnt)
 	//
 	// We always start with a buffer which starts its self with
 	// the mp2 audio sync word and with MAD_BUFFER_GUARD bytes
-	// of the next mp2 frame appended to the current mp2 frame.
+	// for the next mp2 frame appended to the current mp2 frame.
 	// This requires that the previous rest is also of the size
 	// of MAD_BUFFER_GUARD or simply zero at start.
 	//
@@ -339,6 +335,8 @@ int cMP2::Decode(void)
 
     if (!stream.buffer || stream.error == MAD_ERROR_BUFLEN)
 	goto out;
+					// Scan always the header due our
+    frame.header.flags &= ~MAD_FLAG_INCOMPLETE;	// buffer guard workaround
 
     todo = MP2_PLAY;			// We can play
     if (mad_frame_decode(&frame, &stream) == 0)
@@ -393,8 +391,8 @@ void cMP2::Stop (void)
 
 const bool cMP2::Initialize(void)
 {
-    uint_8 * ptr = (uint_8 *)shm_malloc(MP2_BUFFER_SIZE + MAD_BUFFER_GUARD);
-    if (!ptr)
+    uint_8 * ptr = (uint_8 *)shm_malloc(MAD_BUFFER_MDLEN + MAD_BUFFER_GUARD);
+    if (!ptr)				// mad.h says: MAD_BUFFER_MDLEN = 511 + 2048 + MAD_BUFFER_GUARD
 	return false;
     ctr.Lock();
     nextin = ptr;
@@ -580,7 +578,7 @@ resync:
 
     if (test_flags(MP2SPDIF)) {
 	//
-	// If we reach this point, we found a valid AC3 frame to warp into PCM (IEC60958)
+	// If we reach this point, we found a valid MP2 frame to warp into PCM (IEC60958)
 	// accordingly to IEC61937
 	//
 	// What | PCM head              | MP2   payload
@@ -614,8 +612,8 @@ resync:
 	    if (rest + s.buffer_gard > MAD_BUFFER_GUARD)
 		rest = MAD_BUFFER_GUARD - s.buffer_gard;
 
-	    memcpy(&nextin[s.buffer_gard],	 out, rest);	// Head of next buffer
-	    memcpy(&currin[s.pos+s.buffer_gard], out, rest);	// Tail of current buffer
+	    memcpy(&nextin[s.buffer_gard],	 out, rest);	// A dummy head of next buffer
+	    memcpy(&currin[s.pos+s.buffer_gard], out, rest);	// Real tail of current buffer
 	    s.buffer_gard += rest;
 	    out		  += rest;
 	}
