@@ -23,16 +23,13 @@
 #ifndef __MP2_H
 #define __MP2_H
 
+#ifndef HAS_MAD_H
+# error The mad.h header file is mised, please install packages mad and mad-devel!
+#endif
 #include <mad.h>
 #include "types.h"
 #include "iec60958.h"
-#if 1
-# define MP2_BURST_SIZE         192*24
-# define MP2_BUFFER_SIZE	MAD_BUFFER_MDLEN
-#else
-# define MP2_BURST_SIZE         SPDIF_BURST_SIZE
-# define MP2_BUFFER_SIZE	0x4000
-#endif
+#define MP2_BURST_SIZE	192*24
 
 typedef struct _mp2_syncinfo {
     uint_32 sampling_rate;
