@@ -43,12 +43,8 @@ uint_8  * cReplayOutSPDif::pesdata;
 cBounce * cReplayOutSPDif::bounce;
 
 cReplayOutSPDif::cReplayOutSPDif(spdif &dev, ctrl_t &up, cBounce * bPtr, const char *script)
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10300
 :cAudio(), cThread("bso(replay): Forwarding bitstream"),
  ctr(), wait(), SPDIFmute(script), spdifDev(&dev), setup(up)
-#else
-:cAudio(), cThread(), ctr(), wait(), SPDIFmute(script), spdifDev(&dev), setup(up)
-#endif
 {
     flags = 0;
     ctr.Lock();
@@ -149,9 +145,6 @@ void cReplayOutSPDif::Action(void)
 	}
     }
 
-#if defined(VDRVERSNUM) && VDRVERSNUM < 10300
-    dsyslog("REPLAY: Forwarding bitstream thread started (pid=%d)", getpid());
-#endif
     bounce->takeio();
     while (test_flag(ACTIVE)) {
 	ssize_t len;
@@ -190,9 +183,6 @@ void cReplayOutSPDif::Action(void)
     spdifDev->Close(this);
     clear_flag(BOUNDARY);
     curr->Reset();
-#if defined(VDRVERSNUM) && VDRVERSNUM < 10300
-    dsyslog("REPLAY: Forwarding bitstream thread ended (pid=%d)", getpid());
-#endif
 out:
     ctr.Lock();
     stream = NULL;
@@ -205,11 +195,7 @@ out:
     clear_flag(RUNNING);
 }
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 inline bool cReplayOutSPDif::OffsetToDvdOfPS1(const uchar *const b, int &off, const int cnt, const uchar id)
-#else
-inline bool cReplayOutSPDif::OffsetToDvdOfPS1(const uchar *const b, int &off, const int cnt)
-#endif
 {
     const off_t rest = cnt-off;
     bool ret = false;				// DVB streams do not have sub stream headers
@@ -231,20 +217,16 @@ inline bool cReplayOutSPDif::OffsetToDvdOfPS1(const uchar *const b, int &off, co
 	case 0x80 ... 0x87:			// AC3 from e.g. DVD
 	    if (curr != &ac3 || curr->track != tr)
 		break;
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    if (id != ub)
 		break;
-#endif
 	    ret = true;				// found, success
 	    off += 4;
 	    break;
 	case 0x88 ... 0x8f:			// DTS
 	    if (curr != &dts || curr->track != tr)
 		break;
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    if (id != ub)
 		break;
-#endif
 	    ret = true;				// found, success
 	    off += 4;
 	    break;
@@ -264,10 +246,8 @@ inline bool cReplayOutSPDif::OffsetToDvdOfPS1(const uchar *const b, int &off, co
 	    }
 	    if (curr != &pcm || curr->track != tr)
 		break;
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    if (id != ub)
 		break;
-#endif
 	    switch (m & 0x30) {
 	    case 0x00: sample_rate = 48000;
 		break;
@@ -294,11 +274,7 @@ inline bool cReplayOutSPDif::OffsetToDvdOfPS1(const uchar *const b, int &off, co
     return ret;
 }
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 inline bool cReplayOutSPDif::ScanPayOfPS1(const uchar *const b, int &off, const int cnt, const uchar id)
-#else
-inline bool cReplayOutSPDif::ScanPayOfPS1(const uchar *const b, int &off, const int cnt)
-#endif
 {
     const off_t rest = cnt-off;
     cHandle dvb(&b[off], rest);
@@ -327,10 +303,8 @@ inline bool cReplayOutSPDif::ScanPayOfPS1(const uchar *const b, int &off, const
 	    o += 3;
 	    if (o >= rest)			// word magic
 		break;
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    if (id != ub)
 		break;
-#endif
 	    dvb += o;
 	    off += o;
 	    isDVD = true;
@@ -348,10 +322,8 @@ inline bool cReplayOutSPDif::ScanPayOfPS1(const uchar *const b, int &off, const
 	    o += 3;
 	    if (o+2 >= rest)			// double word magic
 		break;
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    if (id != ub)
 		break;
-#endif
 	    dvb += o;
 	    off += o;
 	    isDVD = true;
@@ -384,10 +356,8 @@ inline bool cReplayOutSPDif::ScanPayOfPS1(const uchar *const b, int &off, const
 
 	    if (o >= rest)
 		break;
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    if (id != ub)
 		break;
-#endif
 	    curr = &pcm;
 	    set_setup(AUDIO);
 	    curr->Reset(setup.flags);
@@ -455,11 +425,7 @@ out:
     return (curr != NULL);
 }
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 inline bool cReplayOutSPDif::DigestPayOfMP2(const uchar *const b, int &off, const int cnt, const uchar id)
-#else
-inline bool cReplayOutSPDif::DigestPayOfMP2(const uchar *const b, int &off, const int cnt)
-#endif
 {
     static const uint_32 samplerate_table[3] = {44100, 48000, 32000};
     const off_t rest = cnt-off;
@@ -523,11 +489,7 @@ inline bool cReplayOutSPDif::DigestPayOfMP2(const uchar *const b, int &off, cons
     return (curr != NULL);
 }
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 void cReplayOutSPDif::Play(const uchar *b, int cnt, uchar id)
-#else
-void cReplayOutSPDif::Play(const uchar *b, int cnt)
-#endif
 {
     static uint_16 skip = 0;
     cHandle play(b, cnt);
@@ -587,11 +549,7 @@ void cReplayOutSPDif::Play(const uchar *b, int cnt)
 		// stream identification with the offset to the pay load.
 		if ((flg & 0x00C0) || (flg & 0x0400)) {
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 		    if (!ScanPayOfPS1(&b[0], off, cnt, id))
-#else
-		    if (!ScanPayOfPS1(&b[0], off, cnt))
-#endif
 			goto out;
 		    
 		    ctr.Lock();
@@ -615,7 +573,6 @@ void cReplayOutSPDif::Play(const uchar *b, int cnt)
 		} else
 		    goto out;			// Start only at a boundary of a stream
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    } else if (curr) {
 
 		if (curr->isDVD) {
@@ -632,16 +589,6 @@ void cReplayOutSPDif::Play(const uchar *b, int cnt)
 		    }
 		}
 	    }
-#else
-	    } else if (curr && curr->isDVD) {
-
-		// Check if DVD stream is still valid
-		if (!OffsetToDvdOfPS1(b, off, cnt)) {
-		    Clear();			// Reset
-		    goto out;
-		}
-	    }
-#endif
 	    break;
 	case 0x000001c0 ... 0x000001df:		// Audio of PES Mpeg Audio frame
 	    if (!test_setup(MP2ENABLE))
@@ -666,11 +613,7 @@ void cReplayOutSPDif::Play(const uchar *b, int cnt)
 	    if (!(flg & 0x00C0) && !(flg & 0x0400))
 		goto out;
 
-#if defined(VDRVERSNUM) && VDRVERSNUM >= 10321
 	    if (!DigestPayOfMP2(&b[0], off, cnt, id))
-#else
-	    if (!DigestPayOfMP2(&b[0], off, cnt))
-#endif
 		goto out;
 
 	    ctr.Lock();
