@@ -190,22 +190,23 @@ void spdif::Forward(const uint_8 *const data,
     if (!out || !stream)
 	goto xout;
 
-    ctrlbits &= ~FL_IO;
+    clear_ctrl(IO);
     while (Frame(pcm, head, tail)) {
 
-	if ((ctrlbits & FL_NOEXSYNC) || (ctrlbits & FL_IO))
+	if (ctrlbits & ((1<<FL_NOEXSYNC)|(1<<FL_IO)))
 	    check();
-	ctrlbits |= FL_IO;
+	set_ctrl(IO);
 
-	if (ctrlbits & (FL_FIRST|FL_UNDERRUN|FL_PAUSE|FL_REPEAT|FL_OVERRUN)) {
+	if (ctrlbits & ((1<<FL_FIRST)|(1<<FL_UNDERRUN)|(1<<FL_PAUSE)|(1<<FL_REPEAT)|(1<<FL_OVERRUN))) {
 	    // Let us play with the error detection of the receiver and
 	    // send some of the current bursts twice with error bit set.
 	    static local int repeat;
 
-	    if (ctrlbits & FL_FIRST) {
+	    if (test_ctrl(FIRST)) {
 		uint_32 duration = (B2F(pcm.size)*1000)/stream->SampleRate();
 		int mcnt;
-
+#define USE_MAD_BUFFER_GUARD
+#ifndef USE_MAD_BUFFER_GUARD
 		//
 		// The Mpeg audio decoder requires always two data frames (one full
 		// and the start of the next frame), which we have to receive first,
@@ -213,7 +214,7 @@ void spdif::Forward(const uint_8 *const data,
 		// duration of the almost first resulting PCM frame.
 		//
 		if (opt.audio) duration = 1;
-
+#endif
 		//
 		// If current STC value is not valid, we try next frame
 		// to get the correct pts offset we need the duration of
@@ -231,8 +232,7 @@ void spdif::Forward(const uint_8 *const data,
 
 		// After Pause/Mute in Replay mode our buffer is empty
 		// wheras the buffers of VDR are not.
-		if (ctrlbits & FL_PAUSE) {
-		    ctrlbits &= ~FL_PAUSE;
+		if (test_and_clear_ctrl(PAUSE)) {
 		    offset += pause;
 		    pause = 0;
 		}
@@ -298,17 +298,17 @@ void spdif::Forward(const uint_8 *const data,
 		if (check() == SPDIF_HIGH)
 		    EINTR_RETRY(snd_pcm_wait(out, 10));
 
-		ctrlbits &= ~(FL_FIRST|FL_UNDERRUN);
+		ctrlbits &= ~((1<<FL_FIRST)|(1<<FL_UNDERRUN));
 		repeat = 0;
 	    }
 
-	    if (ctrlbits & FL_UNDERRUN) {
+	    if (test_ctrl(UNDERRUN)) {
 		//
 		// This recovers the underrun in the case we're getting
 		// more input.
 		//
 
-		if (ctrlbits & FL_VRPERIOD) {
+		if (test_ctrl(VRPERIOD)) {
 
 		    Hold(thread);		// Hold the lock on the calling thread
 
@@ -346,12 +346,12 @@ void spdif::Forward(const uint_8 *const data,
 
 		    snd_pcm_drain(out);
 		    snd_pcm_prepare(out);
-		    ctrlbits &= ~FL_UNDERRUN;
+		    clear_ctrl(UNDERRUN);
 
 		    Unhold();			// Do not hold lock on calling thread
 		}
 
-	    } else if (ctrlbits & FL_OVERRUN) {
+	    } else if (test_ctrl(OVERRUN)) {
 		wait.msec(10);
 		//
 		// This is a workaround for overruns.
@@ -384,7 +384,7 @@ void spdif::Forward(const uint_8 *const data,
 	    }
 
 	    // We play now, no Pause nor we Repeat anymore
-	    ctrlbits &= ~(FL_PAUSE|FL_REPEAT);
+	    ctrlbits &= ~((1<<FL_PAUSE)|(1<<FL_REPEAT));
 	}
 
 	if (count > 0) {
@@ -418,7 +418,7 @@ void spdif::burst(const frame_t &pcm)
     if (!writei)
 	goto xout;
 
-    ctrlbits |= FL_BURSTRUN;
+    set_ctrl(BURSTRUN);
     while((frames > 0) && out) {
 	snd_pcm_sframes_t res = 0;
 	if ((res = writei(out, (const void *)data, frames)) < 0) {
@@ -442,7 +442,7 @@ void spdif::burst(const frame_t &pcm)
 		continue;
 	    case -EPIPE:
 		xunderrun();
-		ctrlbits |= FL_FIRST;
+		set_ctrl(FIRST);
 		if (stream)
 		    stream->Clear();
 		delay = 0;
@@ -471,7 +471,7 @@ void spdif::burst(const frame_t &pcm)
 	term   += res;
     }
 xout:
-    ctrlbits &= ~FL_BURSTRUN;
+    clear_ctrl(BURSTRUN);
     stream->pts.lead(term);
 
     return;
@@ -491,7 +491,7 @@ bool spdif::Open(iec60958 *in, cThread *caller)
     if (out)
 	Close();
 
-    ctrlbits = FL_FIRST|FL_NOEXSYNC;
+    ctrlbits = (1<<FL_FIRST)|(1<<FL_NOEXSYNC);
     thread = caller;
 
     if (!Stream(in))
@@ -510,7 +510,7 @@ bool spdif::Open(iec60958 *in, cThread *caller)
     opt.adelay = setup.opt.adelay;
     opt.mmap   = setup.opt.mmap;
     if (setup.opt.variable)
-	ctrlbits |= FL_VRPERIOD;
+	set_ctrl(VRPERIOD);
     opt.type   = setup.opt.type;
     if (test_setup(AUDIO)) {
 	opt.audio = true;
@@ -641,7 +641,6 @@ __diga_end:
 	}
 #define SND_DIR(dir)	(((dir) > 0) ? ("more") : ("less"))
 	dir = 0;
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	if ((err = snd_pcm_hw_params_set_rate_near(out, hwparams, &rate, &dir)) < 0) {
 	    esyslog("S/P-DIF: Sample rate %u not available: %s",
 		    stream->SampleRate(), snd_strerror(err));
@@ -650,40 +649,23 @@ __diga_end:
 	if (dir)
 	    dsyslog("S/P-DIF: Sample rate %d is %s than %d\n",
 		    rate, SND_DIR(dir), stream->SampleRate());
-#else
-	if ((err = snd_pcm_hw_params_set_rate_near(out, hwparams, rate, &dir)) < 0) {
-	    esyslog("S/P-DIF: Sample rate %d not available: %s", rate, snd_strerror(err));
-	    goto err_out;
-	}
-	if (dir)
-	    dsyslog("S/P-DIF: Sample rate is %s than %d\n",
-		    SND_DIR(dir), stream->SampleRate());
-#endif
 
 #define MMAP_BURST	B2F(getpagesize())
 	// Try to use an integer divisor of the burst size as period size
 	// to avoid not needed loops and wait states in burst()
 
 	dir = 0;
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	if ((err = snd_pcm_hw_params_get_period_size_min(hwparams, &period_min, &dir)) < 0) {
 	    esyslog("S/P-DIF: min period size not available: %s", snd_strerror(err));
 	    goto err_out;
 	}
-#else
-	period_min = snd_pcm_hw_params_get_period_size_min(hwparams, &dir);
-#endif
 	if (dir)
 	    dsyslog("S/P-DIF: Minimal period size is %s than %ld\n", SND_DIR(dir), period_min);
 
 	dir = 0;
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	if ((err = snd_pcm_hw_params_get_period_size_max(hwparams, &period_max, &dir)) < 0) {
 	     esyslog("S/P-DIF: max period size not available: %s", snd_strerror(err));
 	}
-#else
-	period_max = snd_pcm_hw_params_get_period_size_max(hwparams, &dir);
-#endif
 	if (dir)
 	    dsyslog("S/P-DIF: Maximal period size is %s than %ld\n", SND_DIR(dir), period_max);
 
@@ -724,19 +706,11 @@ __diga_end:
 
 	if (frag > 1) {
 	    // function returns less than 0 on error or greater than 0
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	    if ((err = snd_pcm_hw_params_set_buffer_size_near(out, hwparams, &val)) < 0) {
 		esyslog("S/P-DIF: Buffer size %lu not available: %s",
 			(unsigned long int)(burst_size*periods), snd_strerror(err));
 		goto err_out;
 	    }
-#else
-	    if ((err = snd_pcm_hw_params_set_buffer_size_near(out, hwparams, val)) < 0) {
-		esyslog("S/P-DIF: Buffer size %lu not available: %s",
-			(unsigned long int)val, snd_strerror(err));
-		goto err_out;
-	    }
-#endif
 	} else {
 	    // function returns less than 0 on error or greater than 0
 	    dir = 0;
@@ -750,18 +724,12 @@ __diga_end:
 
 	// function returns less than 0 on error or greater than 0
 	dir = 0;
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	if ((err = snd_pcm_hw_params_get_period_size(hwparams, &part, &dir)) < 0)
-#else
-	if ((err = snd_pcm_hw_params_get_period_size(hwparams, &dir)) < 0)
-#endif
 	{
 	    esyslog("S/P-DIF: Period size not gotten: %s", snd_strerror(err));
 	    goto err_out;
 	}
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	err = (int)part;
-#endif
 	fragsize = err;
 	err *= frag;
 	if (frag > 1) {
@@ -786,18 +754,12 @@ __diga_end:
 #endif
 
 	// function returns less than 0 on error or greater than 0
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	if ((err = snd_pcm_hw_params_get_buffer_size(hwparams, &part)) < 0)
-#else
-	if ((err = snd_pcm_hw_params_get_buffer_size(hwparams)) < 0)
-#endif
 	{
 	    esyslog("S/P-DIF: Buffer size not set: %s", snd_strerror(err));
 	    goto err_out;
 	}
-#if defined(SND_LIB_MAJOR) && SND_LIB_MAJOR >= 1
 	err = (int)part;
-#endif
 	if (period_size * periods != (snd_pcm_uframes_t)err) {
 	    esyslog("S/P-DIF: Buffer size not set: %s", snd_strerror(err));
 	    goto err_out;
@@ -813,7 +775,7 @@ __diga_end:
 	}
 
 	if (snd_pcm_hw_params_can_pause(hwparams) == 1)
-	    ctrlbits |= FL_CANPAUSE;
+	    set_ctrl(CANPAUSE);
 
 	if ((err = snd_pcm_hw_params(out, hwparams)) < 0) {
 	    esyslog("S/P-DIF: Cannot set buffer size");
@@ -921,7 +883,7 @@ void spdif::Close(cThread *caller)
         goto err;
 
     Unhold();					// Leave any thead lock if any
-    while (ctrlbits & FL_BURSTRUN)
+    while (test_ctrl(BURSTRUN))
 	wait.msec(1);
     if (caller) Hold(caller);			// Hold lock for pause or stop frame
     Clear(exit);
@@ -969,9 +931,9 @@ void spdif::Clear(bool exit)
     if (!out)
 	goto xout;
 
-    ctrlbits |= FL_PAUSE;			// Mute all
+    set_ctrl(PAUSE);				// Mute all
 
-    if (ctrlbits & FL_FIRST)
+    if (test_ctrl(FIRST))
 	goto xout;
 
     if ((err = snd_pcm_status(out, status)) < 0) {
@@ -983,7 +945,7 @@ void spdif::Clear(bool exit)
     case SND_PCM_STATE_RUNNING:
 
 	if (exit) {
-	    ctrlbits &= ~FL_PAUSE;
+	    clear_ctrl(PAUSE);
 	    pause = 0;				// VDR has cleared its buffers
 
 	    if (stream) {
@@ -996,6 +958,7 @@ void spdif::Clear(bool exit)
 
 	    if (opt.mmap) {
 		// In case of mmap access we've to wait
+		(void)snd_pcm_hwsync(out);
 		delay = snd_pcm_avail_update(out);
 		int maxloop = delay/fragsize + 1;
 		while ((delay > 0) && (maxloop-- > 0)) {
@@ -1026,12 +989,13 @@ void spdif::Clear(bool exit)
 		    break;
 		if (!test_setup(STILLPIC))	// Only for still pictures
 		    break;
-		if (ctrlbits & FL_FIRST)	// Already stopped
+		if (test_ctrl(FIRST))		// Already stopped
 		    break;
 		if (!stream)	 		// No stream open
 		    break;
 
 		// Calculate addon of start delay in ms
+		(void)snd_pcm_hwsync(out);
 		if (snd_pcm_delay(out, &pause) < 0)
 		    pause = 0;
 		else
@@ -1058,7 +1022,7 @@ void spdif::Clear(bool exit)
 	    esyslog("S/P-DIF: clear: prepare error: %s", snd_strerror(err));
 	// fall through
     case SND_PCM_STATE_PREPARED:
-	ctrlbits |= FL_FIRST;
+	set_ctrl(FIRST);
 	if (stream)
 	    stream->Clear();
 	break;
@@ -1081,12 +1045,12 @@ bool spdif::Synchronize(class cBounce *bounce)
     if (test_setup(CLEAR))
 	return false;
 
-    if (ctrlbits & FL_FIRST)
+    if (test_ctrl(FIRST))
 	goto do_wait;
 
     Unhold();				// Leave any thead lock if any
 
-    ctrlbits &= ~FL_NOEXSYNC;
+    clear_ctrl(NOEXSYNC);
 
 repeat:
     if (!out)
@@ -1138,7 +1102,7 @@ repeat:
 	    esyslog("S/P-DIF: synchronize: prepare error: %s", snd_strerror(err));
 	// fall through
     case SND_PCM_STATE_PREPARED:
-	ctrlbits |= FL_FIRST;
+	set_ctrl(FIRST);
 	if (stream)
 	    stream->Clear();
 	goto do_wait;
@@ -1149,13 +1113,13 @@ xout:
     return ready;
 
 do_wait:
-    if (ctrlbits & FL_PAUSE)		// Pause active
+    if (test_ctrl(PAUSE))		// Pause active
 	wait = 30;
     else
 	wait = SPDIF_TIMEOUT;
     ready = bounce->poll(wait);
 
-    return (ctrlbits & FL_PAUSE) ? true : ready;
+    return (test_ctrl(PAUSE)) ? true : ready;
 }
 
 inline bool spdif::xrepeat(void)
@@ -1163,13 +1127,13 @@ inline bool spdif::xrepeat(void)
     bool ret = true;
     frame_t pcm;
 
-    if (ctrlbits & FL_REPEAT) {
+    if (test_ctrl(REPEAT)) {
 	struct timeval now, diff;
 	gettimeofday(&now, NULL);
 	timersub(&now, &xrstart, &diff);
         ret = ((diff.tv_sec*1000 + diff.tv_usec/1000) < SPDIF_REPEAT);
     } else {
-	ctrlbits |= FL_REPEAT;
+	set_ctrl(REPEAT);
 	gettimeofday(&xrstart, NULL);
     }
     if (ret && stream && (pcm = stream->Frame()).burst)
@@ -1274,20 +1238,22 @@ int spdif::check(snd_pcm_status_t * status)
     int grade = SPDIF_LOW;
     delay = 0;
 
-    if (ctrlbits & FL_FIRST)	// No AC3 running is LOW
+    if (test_ctrl(FIRST))	// No AC3 running is LOW
 	return grade;
 
     if (status)
 	delay = snd_pcm_status_get_delay(status);
-    else
-	if (ctrlbits & FL_FIRST)
+    else {
+	(void)snd_pcm_hwsync(out);
+	if (opt.mmap || test_ctrl(FIRST))
 	    delay = snd_pcm_avail_update(out);
 	else
 	    snd_pcm_delay(out, &delay);
+    }
 
     if (delay < 0) {
 	xunderrun();
-	ctrlbits |= FL_FIRST;
+	set_ctrl(FIRST);
 	if (stream)
 	    stream->Clear();
 	delay = 0;
@@ -1296,16 +1262,16 @@ int spdif::check(snd_pcm_status_t * status)
 
     // Underrun dection for setting variable period size
     if      ((snd_pcm_uframes_t)delay <= buf.lower)
-	ctrlbits |= FL_UNDERRUN;
+	set_ctrl(UNDERRUN);
     else if ((snd_pcm_uframes_t)delay >  buf.upper)
-	ctrlbits &= ~FL_UNDERRUN;
+	clear_ctrl(UNDERRUN);
 
     // Buffer check
-    ctrlbits &= ~FL_OVERRUN;
+    clear_ctrl(OVERRUN);
     if      ((snd_pcm_uframes_t)delay <  buf.alarm)
 	grade = SPDIF_LOW;
     else if ((snd_pcm_uframes_t)delay >  buf.high) {
-	ctrlbits |= FL_OVERRUN;
+	set_ctrl(OVERRUN);
 	grade = SPDIF_HIGH;
     } else
 	grade = SPDIF_OK;
@@ -1329,7 +1295,7 @@ size_t spdif::Available(const size_t max)
 	switch (check()) {
 	default:
 	case SPDIF_LOW:
-	    if (ctrlbits & FL_FIRST)
+	    if (test_ctrl(FIRST))
 		break;
 	case SPDIF_OK:			// Fill up to upper boundary (and empty bounce buffer)
 	    initial = delay + 3*burst_size;
@@ -1344,7 +1310,7 @@ size_t spdif::Available(const size_t max)
 	}
     }
 
-    if (ctrlbits & FL_FIRST) {		// Be able to start without delay
+    if (test_ctrl(FIRST)) {		// Be able to start without delay
 	initial = silent.size*opt.first + 3*burst_size;
 	if (initial >= buffer_size)
 	    goto xout;			// hold data in bounce buffer
@@ -1367,7 +1333,7 @@ xout:
 void spdif::Pause(const bool onoff)
 {
     if (onoff) {
-	ctrlbits |= FL_PAUSE;
+	set_ctrl(PAUSE);
     }   // else {
 	// FL_PAUSE will be unset in Forward()
 	// }
