@@ -25,6 +25,9 @@
 
 #include <sys/time.h>
 #include <signal.h>
+#ifndef HAS_ASOUNDLIB_H
+# error error The file /usr/include/alsa/asoundlib.h is missed, install e.g. alsa-devel!
+#endif
 #include <alsa/asoundlib.h>
 #include <vdr/thread.h>
 #include "iec60958.h"
@@ -90,18 +93,23 @@ private:
     snd_output_t *log;
     snd_aes_iec958_t ch;
     enum {
-	FL_FIRST    = 0x00000001,	// Start and after Pause
-	FL_IO       = 0x00000002,	// More frames in Forward() handled
-	FL_CANPAUSE = 0x00000004,	// Hardware can do pause
-	FL_UNDERRUN = 0x00000008,	// Underrun detected
-	FL_VRPERIOD = 0x00000010,	// double frames in case of underrun
-	FL_NOEXSYNC = 0x00000020,	// Synchronize() was not called before
-	FL_BURSTRUN = 0x00000040,	// burst() active
-	FL_PAUSE    = 0x00000080,	// Pause() called
-	FL_OVERRUN  = 0x00000100,	// Overrun detected
-	FL_REPEAT   = 0x00000200	// Repeat last frame upto 1 second
+	FL_FIRST    = 1,	// Start and after Pause
+	FL_IO       = 2,	// More frames in Forward() handled
+	FL_CANPAUSE = 3,	// Hardware can do pause
+	FL_UNDERRUN = 4,	// Underrun detected
+	FL_VRPERIOD = 5,	// double frames in case of underrun
+	FL_NOEXSYNC = 6,	// Synchronize() was not called before
+	FL_BURSTRUN = 7,	// burst() active
+	FL_PAUSE    = 8,	// Pause() called
+	FL_OVERRUN  = 9,	// Overrun detected
+	FL_REPEAT   = 10	// Repeat last frame upto 1 second
     };
-    uint_32 ctrlbits;
+    flags_t ctrlbits;
+#   define test_and_set_ctrl(ctrl)         test_and_set_bit  (FL_ ## ctrl, &ctrlbits)
+#   define test_and_clear_ctrl(ctrl)       test_and_clear_bit(FL_ ## ctrl, &ctrlbits)
+#   define test_ctrl(ctrl)                 test_bit (FL_ ## ctrl, &ctrlbits)
+#   define set_ctrl(ctrl)                  set_bit  (FL_ ## ctrl, &ctrlbits)
+#   define clear_ctrl(ctrl)                clear_bit(FL_ ## ctrl, &ctrlbits)
     virtual void burst(const frame_t &pcm);
     struct timeval xrstart;
     inline bool xrepeat(void);
