@@ -24,30 +24,98 @@
 
 #include <unistd.h>
 #include <sys/mman.h>
-#include <asm/types.h>
 #include <sys/types.h>
-#if defined(__i386__) || defined(__x86_64__)
-# include <asm/bitops.h>
-#else
-# define clear_bit(n,addr)  (*(addr) &= ~(1 << (n)))
-# define set_bit(n,addr)    (*(addr) |= (1 << (n)))
-# define test_bit(n,addr)   (*(addr) & (1 << (n)))
-int inline test_and_set_bit(int n, volatile void *a)
-{
-    int *addr = (int *)a;
-    int result = test_bit(n, addr);
-    set_bit(n, addr);
-    return result;
-}
-
-int inline test_and_clear_bit(int n, volatile void *a)
-{
-    int *addr = (int *)a;
-    int result = test_bit(n, addr);
-    clear_bit(n, addr);
-    return result;
-}
+#if defined(HAS_CDEFS_H)
+# include <sys/cdefs.h>
 #endif
+#ifndef  __always_inline
+# define __always_inline inline
+#endif
+#ifndef __vasm
+# define __vasm __asm__ __volatile__
+#endif
+extern "C" {
+#if defined(__i386__) 
+    extern __always_inline void clear_bit(int nr, volatile unsigned long * addr)
+    {
+	__vasm ("btrl %1,%0" :"+m" (*(volatile long *)addr) :"Ir" (nr));
+    }
+    extern __always_inline void set_bit(int nr, volatile unsigned long * addr)
+    {
+        __vasm ("btsl %1,%0" :"+m" (*(volatile long *)addr) :"Ir" (nr));
+    }
+    extern __always_inline int test_bit(int nr, const volatile unsigned long * addr)
+    {
+	int oldbit;
+	__vasm ("btl %2,%1\n\tsbbl %0,%0" :"=r" (oldbit) :"m" (*(volatile long *)addr),"Ir" (nr));
+	return oldbit;
+    }
+    extern __always_inline int test_and_set_bit(int nr, volatile unsigned long * addr)
+    {
+	int oldbit;
+	__vasm ("btsl %2,%1\n\tsbbl %0,%0" :"=r" (oldbit),"+m" (*(volatile long *)addr) :"Ir" (nr) :"memory");
+	return oldbit;
+    }
+    extern __always_inline int test_and_clear_bit(int nr, volatile unsigned long * addr)
+    {
+	int oldbit;
+	__vasm ("btrl %2,%1\n\tsbbl %0,%0" :"=r" (oldbit),"+m" (*(volatile long *)addr) :"Ir" (nr) :"memory");
+	return oldbit;
+    }
+#elif defined(__x86_64__)
+    extern __always_inline void clear_bit(int nr, volatile void * addr)
+    {
+	__vasm ("btrl %1,%0" :"+m" (*(volatile long *)addr) :"dIr" (nr));
+    }
+    extern __always_inline void set_bit(int nr, volatile void * addr)
+    {
+        __vasm ("btsl %1,%0" :"+m" (*(volatile long *)addr) :"dIr" (nr));
+    }
+    extern __always_inline int test_bit(int nr, const volatile void * addr)
+    {
+	int oldbit;
+	__vasm ("btl %2,%1\n\tsbbl %0,%0" :"=r" (oldbit) :"m" (*(volatile long *)addr),"dIr" (nr));
+	return oldbit;
+    }
+    extern __always_inline int test_and_set_bit(int nr, volatile void * addr)
+    {
+	int oldbit;
+	__vasm ("btsl %2,%1\n\tsbbl %0,%0" :"=r" (oldbit),"+m" (*(volatile long *)addr) :"dIr" (nr) :"memory");
+	return oldbit;
+    }
+    extern __always_inline int test_and_clear_bit(int nr, volatile void * addr)
+    {
+	int oldbit;
+	__vasm ("btrl %2,%1\n\tsbbl %0,%0" :"=r" (oldbit),"+m" (*(volatile long *)addr) :"dIr" (nr) :"memory");
+	return oldbit;
+    }
+#else
+    extern __always_inline void clear_bit(int nr, volatile void * addr)
+    {
+	*(volatile long *)addr &= ~(1 << (nr));
+    }
+    extern __always_inline void set_bit(int nr, volatile void * addr)
+    {
+        *(volatile long *)addr |= (1 << (nr));
+    }
+    extern __always_inline int test_bit(int nr, const volatile void * addr)
+    {
+	return (*(volatile long *)addr) & (1 << (nr));
+    }
+    extern __always_inline int test_and_set_bit(int nr, volatile void * addr)
+    {
+	int oldbit = test_bit(nr, addr);
+	set_bit(nr, addr);
+	return oldbit;
+    }
+    extern __always_inline int test_and_clear_bit(int nr, volatile void * addr)
+    {
+	int oldbit = test_bit(nr, addr);
+	clear_bit(nr, addr);
+	return oldbit;
+    }
+#endif
+};
 
 #ifndef AARONS_TYPES
 #define AARONS_TYPES
